.. role:: hidden
    :class: hidden-section


Data Generators
===============

.. currentmodule:: sconce.data_generators


:hidden:`DataGenerator`
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: DataGenerator
    :members:


:hidden:`ImageDataGenerator`
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: ImageDataGenerator
    :members:
